# This file was auto-generated by Fern from our API Definition.

import typing
import uuid

from ..common.types.collaborator import Collaborator
from ..common.types.resource_identifier import ResourceIdentifier
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from .raw_client import AsyncRawDocumentCollectionsClient, RawDocumentCollectionsClient
from .types.create_collection_response import CreateCollectionResponse
from .types.delete_collection_response import DeleteCollectionResponse
from .types.list_documents_in_collection_response import ListDocumentsInCollectionResponse
from .types.mongo_collection_sync_config import MongoCollectionSyncConfig
from .types.mongo_collection_sync_response import MongoCollectionSyncResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class DocumentCollectionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawDocumentCollectionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawDocumentCollectionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawDocumentCollectionsClient
        """
        return self._raw_client

    def add_documents_to_collection(
        self,
        *,
        collection_id: uuid.UUID,
        resource_identifiers: typing.Sequence[ResourceIdentifier],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Add documents to a document collection. Note that the documents must already exist in the document catalog to use this endpoint. If you want to upload a new document to a collection, use the `uploadDocumentContents` endpoint.

        Parameters
        ----------
        collection_id : uuid.UUID
            The ID of the document collection you want to add to.

        resource_identifiers : typing.Sequence[ResourceIdentifier]
            The set of resource identifier for which you want to add to the collection.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import uuid

        from credal import CredalApi
        from credal.common import ResourceIdentifier_ExternalResourceId

        client = CredalApi(
            api_key="YOUR_API_KEY",
        )
        client.document_collections.add_documents_to_collection(
            collection_id=uuid.UUID(
                "82e4b12a-6990-45d4-8ebd-85c00e030c24",
            ),
            resource_identifiers=[
                ResourceIdentifier_ExternalResourceId(
                    external_resource_id="170NrBm0Do7gdzvr54UvyslPVWkQFOA0lgNycFmdZJQr",
                    resource_type="GOOGLE_DRIVE_ITEM",
                ),
                ResourceIdentifier_ExternalResourceId(
                    external_resource_id="398KAHdfkjsdf09r54UvyslPVWkQFOA0lOiu34in923",
                    resource_type="GOOGLE_DRIVE_ITEM",
                ),
            ],
        )
        """
        _response = self._raw_client.add_documents_to_collection(
            collection_id=collection_id, resource_identifiers=resource_identifiers, request_options=request_options
        )
        return _response.data

    def remove_documents_from_collection(
        self,
        *,
        collection_id: uuid.UUID,
        resource_identifiers: typing.Sequence[ResourceIdentifier],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Remove documents from a collection

        Parameters
        ----------
        collection_id : uuid.UUID
            The ID of the document collection you want to add to.

        resource_identifiers : typing.Sequence[ResourceIdentifier]
            The set of resource identifier for which you want to remove from the collection

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import uuid

        from credal import CredalApi
        from credal.common import ResourceIdentifier_ExternalResourceId

        client = CredalApi(
            api_key="YOUR_API_KEY",
        )
        client.document_collections.remove_documents_from_collection(
            collection_id=uuid.UUID(
                "82e4b12a-6990-45d4-8ebd-85c00e030c24",
            ),
            resource_identifiers=[
                ResourceIdentifier_ExternalResourceId(
                    external_resource_id="170NrBm0Do7gdzvr54UvyslPVWkQFOA0lgNycFmdZJQr",
                    resource_type="GOOGLE_DRIVE_ITEM",
                ),
                ResourceIdentifier_ExternalResourceId(
                    external_resource_id="398KAHdfkjsdf09r54UvyslPVWkQFOA0lOiu34in923",
                    resource_type="GOOGLE_DRIVE_ITEM",
                ),
            ],
        )
        """
        _response = self._raw_client.remove_documents_from_collection(
            collection_id=collection_id, resource_identifiers=resource_identifiers, request_options=request_options
        )
        return _response.data

    def list_documents_in_collection(
        self, *, collection_id: uuid.UUID, request_options: typing.Optional[RequestOptions] = None
    ) -> ListDocumentsInCollectionResponse:
        """
        List documents in a collection

        Parameters
        ----------
        collection_id : uuid.UUID
            The ID of the document collection to list documents from.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListDocumentsInCollectionResponse

        Examples
        --------
        import uuid

        from credal import CredalApi

        client = CredalApi(
            api_key="YOUR_API_KEY",
        )
        client.document_collections.list_documents_in_collection(
            collection_id=uuid.UUID(
                "82e4b12a-6990-45d4-8ebd-85c00e030c24",
            ),
        )
        """
        _response = self._raw_client.list_documents_in_collection(
            collection_id=collection_id, request_options=request_options
        )
        return _response.data

    def create_collection(
        self,
        *,
        name: str,
        description: str,
        collaborators: typing.Sequence[Collaborator],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateCollectionResponse:
        """
        Create a new collection. The API key used will be added to the collection for future Requests

        Parameters
        ----------
        name : str
            A descriptive name for the collection.

        description : str
            An in depth name for the agent's function. Useful for routing requests to the right agent.

        collaborators : typing.Sequence[Collaborator]
            A list of collaborator emails and roles that will have access to the agent.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateCollectionResponse

        Examples
        --------
        from credal import CredalApi
        from credal.common import Collaborator

        client = CredalApi(
            api_key="YOUR_API_KEY",
        )
        client.document_collections.create_collection(
            name="Customer Collection",
            description="This collection is used to answer customer requests based on internal documentation.",
            collaborators=[
                Collaborator(
                    email="test@gmail.com",
                    role="editor",
                )
            ],
        )
        """
        _response = self._raw_client.create_collection(
            name=name, description=description, collaborators=collaborators, request_options=request_options
        )
        return _response.data

    def delete_collection(
        self, *, collection_id: uuid.UUID, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteCollectionResponse:
        """
        Delete the collection.

        Parameters
        ----------
        collection_id : uuid.UUID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteCollectionResponse

        Examples
        --------
        import uuid

        from credal import CredalApi

        client = CredalApi(
            api_key="YOUR_API_KEY",
        )
        client.document_collections.delete_collection(
            collection_id=uuid.UUID(
                "ac20e6ba-0bae-11ef-b25a-efca73df4c3a",
            ),
        )
        """
        _response = self._raw_client.delete_collection(collection_id=collection_id, request_options=request_options)
        return _response.data

    def create_mongo_collection_sync(
        self,
        *,
        collection_id: uuid.UUID,
        mongo_uri: str,
        config: MongoCollectionSyncConfig,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> MongoCollectionSyncResponse:
        """
        Credal lets you easily sync your MongoDB data for use in Collections and Agents. Create a new sync from a MongoDB collection to a Credal collection.

        Parameters
        ----------
        collection_id : uuid.UUID

        mongo_uri : str

        config : MongoCollectionSyncConfig

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        MongoCollectionSyncResponse

        Examples
        --------
        import uuid

        from credal import CredalApi
        from credal.document_collections import (
            MongoCollectionSyncConfig,
            MongoSourceFieldsConfig,
        )

        client = CredalApi(
            api_key="YOUR_API_KEY",
        )
        client.document_collections.create_mongo_collection_sync(
            mongo_uri="mongodb+srv://cluster0.abcdefg.mongodb.net/Cluster0?retryWrites=true&w=majority",
            collection_id=uuid.UUID(
                "ac20e6ba-0bae-11ef-b25a-efca73df4c3a",
            ),
            config=MongoCollectionSyncConfig(
                sync_name="My sales transcripts",
                collection_name="myCollection",
                filter_expression={"status": {"$ne": "disabled"}},
                source_fields=MongoSourceFieldsConfig(
                    body="body",
                    source_name="meetingName",
                    source_system_updated="transcriptDatetime",
                    source_url="link",
                ),
            ),
        )
        """
        _response = self._raw_client.create_mongo_collection_sync(
            collection_id=collection_id, mongo_uri=mongo_uri, config=config, request_options=request_options
        )
        return _response.data

    def update_mongo_collection_sync(
        self,
        *,
        mongo_credential_id: uuid.UUID,
        mongo_uri: str,
        config: MongoCollectionSyncConfig,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> MongoCollectionSyncResponse:
        """
        Credal lets you easily sync your MongoDB data for use in Collections and Agents. Update an existing sync from a MongoDB collection to a Credal collection via the `mongoCredentialId`, to disambiguate between multiple potential syncs to a given collection.

        Parameters
        ----------
        mongo_credential_id : uuid.UUID

        mongo_uri : str

        config : MongoCollectionSyncConfig

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        MongoCollectionSyncResponse

        Examples
        --------
        import uuid

        from credal import CredalApi
        from credal.document_collections import (
            MongoCollectionSyncConfig,
            MongoSourceFieldsConfig,
        )

        client = CredalApi(
            api_key="YOUR_API_KEY",
        )
        client.document_collections.update_mongo_collection_sync(
            mongo_uri="mongodb+srv://cluster0.abcdefg.mongodb.net/Cluster0?retryWrites=true&w=majority",
            mongo_credential_id=uuid.UUID(
                "5988ed76-6ee1-11ef-97dd-1fca54b7c4bc",
            ),
            config=MongoCollectionSyncConfig(
                sync_name="My recent summarized sales transcripts",
                collection_name="myCollection",
                filter_expression={
                    "transcriptDatetime": {"$gt": "2023-01-01T00:00:00.000Z"}
                },
                source_fields=MongoSourceFieldsConfig(
                    body="transcriptSummary",
                    source_name="meetingName",
                    source_system_updated="transcriptDatetime",
                    source_url="link",
                ),
            ),
        )
        """
        _response = self._raw_client.update_mongo_collection_sync(
            mongo_credential_id=mongo_credential_id, mongo_uri=mongo_uri, config=config, request_options=request_options
        )
        return _response.data


class AsyncDocumentCollectionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawDocumentCollectionsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawDocumentCollectionsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawDocumentCollectionsClient
        """
        return self._raw_client

    async def add_documents_to_collection(
        self,
        *,
        collection_id: uuid.UUID,
        resource_identifiers: typing.Sequence[ResourceIdentifier],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Add documents to a document collection. Note that the documents must already exist in the document catalog to use this endpoint. If you want to upload a new document to a collection, use the `uploadDocumentContents` endpoint.

        Parameters
        ----------
        collection_id : uuid.UUID
            The ID of the document collection you want to add to.

        resource_identifiers : typing.Sequence[ResourceIdentifier]
            The set of resource identifier for which you want to add to the collection.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio
        import uuid

        from credal import AsyncCredalApi
        from credal.common import ResourceIdentifier_ExternalResourceId

        client = AsyncCredalApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.document_collections.add_documents_to_collection(
                collection_id=uuid.UUID(
                    "82e4b12a-6990-45d4-8ebd-85c00e030c24",
                ),
                resource_identifiers=[
                    ResourceIdentifier_ExternalResourceId(
                        external_resource_id="170NrBm0Do7gdzvr54UvyslPVWkQFOA0lgNycFmdZJQr",
                        resource_type="GOOGLE_DRIVE_ITEM",
                    ),
                    ResourceIdentifier_ExternalResourceId(
                        external_resource_id="398KAHdfkjsdf09r54UvyslPVWkQFOA0lOiu34in923",
                        resource_type="GOOGLE_DRIVE_ITEM",
                    ),
                ],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.add_documents_to_collection(
            collection_id=collection_id, resource_identifiers=resource_identifiers, request_options=request_options
        )
        return _response.data

    async def remove_documents_from_collection(
        self,
        *,
        collection_id: uuid.UUID,
        resource_identifiers: typing.Sequence[ResourceIdentifier],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Remove documents from a collection

        Parameters
        ----------
        collection_id : uuid.UUID
            The ID of the document collection you want to add to.

        resource_identifiers : typing.Sequence[ResourceIdentifier]
            The set of resource identifier for which you want to remove from the collection

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio
        import uuid

        from credal import AsyncCredalApi
        from credal.common import ResourceIdentifier_ExternalResourceId

        client = AsyncCredalApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.document_collections.remove_documents_from_collection(
                collection_id=uuid.UUID(
                    "82e4b12a-6990-45d4-8ebd-85c00e030c24",
                ),
                resource_identifiers=[
                    ResourceIdentifier_ExternalResourceId(
                        external_resource_id="170NrBm0Do7gdzvr54UvyslPVWkQFOA0lgNycFmdZJQr",
                        resource_type="GOOGLE_DRIVE_ITEM",
                    ),
                    ResourceIdentifier_ExternalResourceId(
                        external_resource_id="398KAHdfkjsdf09r54UvyslPVWkQFOA0lOiu34in923",
                        resource_type="GOOGLE_DRIVE_ITEM",
                    ),
                ],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.remove_documents_from_collection(
            collection_id=collection_id, resource_identifiers=resource_identifiers, request_options=request_options
        )
        return _response.data

    async def list_documents_in_collection(
        self, *, collection_id: uuid.UUID, request_options: typing.Optional[RequestOptions] = None
    ) -> ListDocumentsInCollectionResponse:
        """
        List documents in a collection

        Parameters
        ----------
        collection_id : uuid.UUID
            The ID of the document collection to list documents from.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ListDocumentsInCollectionResponse

        Examples
        --------
        import asyncio
        import uuid

        from credal import AsyncCredalApi

        client = AsyncCredalApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.document_collections.list_documents_in_collection(
                collection_id=uuid.UUID(
                    "82e4b12a-6990-45d4-8ebd-85c00e030c24",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list_documents_in_collection(
            collection_id=collection_id, request_options=request_options
        )
        return _response.data

    async def create_collection(
        self,
        *,
        name: str,
        description: str,
        collaborators: typing.Sequence[Collaborator],
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateCollectionResponse:
        """
        Create a new collection. The API key used will be added to the collection for future Requests

        Parameters
        ----------
        name : str
            A descriptive name for the collection.

        description : str
            An in depth name for the agent's function. Useful for routing requests to the right agent.

        collaborators : typing.Sequence[Collaborator]
            A list of collaborator emails and roles that will have access to the agent.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateCollectionResponse

        Examples
        --------
        import asyncio

        from credal import AsyncCredalApi
        from credal.common import Collaborator

        client = AsyncCredalApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.document_collections.create_collection(
                name="Customer Collection",
                description="This collection is used to answer customer requests based on internal documentation.",
                collaborators=[
                    Collaborator(
                        email="test@gmail.com",
                        role="editor",
                    )
                ],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_collection(
            name=name, description=description, collaborators=collaborators, request_options=request_options
        )
        return _response.data

    async def delete_collection(
        self, *, collection_id: uuid.UUID, request_options: typing.Optional[RequestOptions] = None
    ) -> DeleteCollectionResponse:
        """
        Delete the collection.

        Parameters
        ----------
        collection_id : uuid.UUID

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        DeleteCollectionResponse

        Examples
        --------
        import asyncio
        import uuid

        from credal import AsyncCredalApi

        client = AsyncCredalApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.document_collections.delete_collection(
                collection_id=uuid.UUID(
                    "ac20e6ba-0bae-11ef-b25a-efca73df4c3a",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete_collection(
            collection_id=collection_id, request_options=request_options
        )
        return _response.data

    async def create_mongo_collection_sync(
        self,
        *,
        collection_id: uuid.UUID,
        mongo_uri: str,
        config: MongoCollectionSyncConfig,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> MongoCollectionSyncResponse:
        """
        Credal lets you easily sync your MongoDB data for use in Collections and Agents. Create a new sync from a MongoDB collection to a Credal collection.

        Parameters
        ----------
        collection_id : uuid.UUID

        mongo_uri : str

        config : MongoCollectionSyncConfig

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        MongoCollectionSyncResponse

        Examples
        --------
        import asyncio
        import uuid

        from credal import AsyncCredalApi
        from credal.document_collections import (
            MongoCollectionSyncConfig,
            MongoSourceFieldsConfig,
        )

        client = AsyncCredalApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.document_collections.create_mongo_collection_sync(
                mongo_uri="mongodb+srv://cluster0.abcdefg.mongodb.net/Cluster0?retryWrites=true&w=majority",
                collection_id=uuid.UUID(
                    "ac20e6ba-0bae-11ef-b25a-efca73df4c3a",
                ),
                config=MongoCollectionSyncConfig(
                    sync_name="My sales transcripts",
                    collection_name="myCollection",
                    filter_expression={"status": {"$ne": "disabled"}},
                    source_fields=MongoSourceFieldsConfig(
                        body="body",
                        source_name="meetingName",
                        source_system_updated="transcriptDatetime",
                        source_url="link",
                    ),
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_mongo_collection_sync(
            collection_id=collection_id, mongo_uri=mongo_uri, config=config, request_options=request_options
        )
        return _response.data

    async def update_mongo_collection_sync(
        self,
        *,
        mongo_credential_id: uuid.UUID,
        mongo_uri: str,
        config: MongoCollectionSyncConfig,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> MongoCollectionSyncResponse:
        """
        Credal lets you easily sync your MongoDB data for use in Collections and Agents. Update an existing sync from a MongoDB collection to a Credal collection via the `mongoCredentialId`, to disambiguate between multiple potential syncs to a given collection.

        Parameters
        ----------
        mongo_credential_id : uuid.UUID

        mongo_uri : str

        config : MongoCollectionSyncConfig

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        MongoCollectionSyncResponse

        Examples
        --------
        import asyncio
        import uuid

        from credal import AsyncCredalApi
        from credal.document_collections import (
            MongoCollectionSyncConfig,
            MongoSourceFieldsConfig,
        )

        client = AsyncCredalApi(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.document_collections.update_mongo_collection_sync(
                mongo_uri="mongodb+srv://cluster0.abcdefg.mongodb.net/Cluster0?retryWrites=true&w=majority",
                mongo_credential_id=uuid.UUID(
                    "5988ed76-6ee1-11ef-97dd-1fca54b7c4bc",
                ),
                config=MongoCollectionSyncConfig(
                    sync_name="My recent summarized sales transcripts",
                    collection_name="myCollection",
                    filter_expression={
                        "transcriptDatetime": {"$gt": "2023-01-01T00:00:00.000Z"}
                    },
                    source_fields=MongoSourceFieldsConfig(
                        body="transcriptSummary",
                        source_name="meetingName",
                        source_system_updated="transcriptDatetime",
                        source_url="link",
                    ),
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update_mongo_collection_sync(
            mongo_credential_id=mongo_credential_id, mongo_uri=mongo_uri, config=config, request_options=request_options
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from . import common, copilots, document_catalog, document_collections, search, users
    from .client import AsyncCredalApi, CredalApi
    from .common import (
        Collaborator,
        CustomMetadataValue,
        ExternalResourceId,
        Operator,
        ResourceIdentifier,
        ResourceIdentifier_ExternalResourceId,
        ResourceIdentifier_Url,
        ResourceType,
        Role,
        Url,
    )
    from .copilots import (
        AiEndpointConfiguration,
        BlockedChunk,
        BooleanFieldSchema,
        CollectionFilteredData,
        Configuration,
        CreateConversationResponse,
        CreateCopilotResponse,
        DataChunk,
        DataFilter,
        DatetimeFieldSchema,
        DeleteCopilotResponse,
        EndOfMessageChunk,
        ErrorChunk,
        ErrorChunkData,
        ExportCopilotsResponse,
        ExportedCopilot,
        FeedbackEnum,
        Filter,
        Filter_Boolean,
        Filter_Datetime,
        Filter_Number,
        Filter_String,
        FinalChunk,
        InitialChunk,
        InputVariable,
        InsertedAuditLog,
        MessageBlocked,
        MessageFeedback,
        MessageReply,
        NumberFieldSchema,
        ReferencedSource,
        ResponseChunk,
        SendAgentMessageResponse,
        SendMessageResponse,
        SendMessageResponse_AiResponseResult,
        SendMessageResponse_BlockedResult,
        StreamingChunk,
        StreamingChunk_Blocked,
        StreamingChunk_DataChunk,
        StreamingChunk_EndOfMessage,
        StreamingChunk_ErrorChunk,
        StreamingChunk_FinalChunk,
        StreamingChunk_Initial,
        StringFieldSchema,
        WebSearchResult,
    )
    from .document_catalog import (
        DocumentMetadataPatch,
        DocumentMetadataPatchRequest,
        SyncSourceByUrlRequest,
        SyncSourceByUrlResponse,
        UploadDocumentResponse,
    )
    from .document_collections import (
        CreateCollectionResponse,
        DeleteCollectionResponse,
        ListDocumentsInCollectionResponse,
        MongoCollectionSyncConfig,
        MongoCollectionSyncResponse,
        MongoSourceFieldsConfig,
    )
    from .environment import CredalApiEnvironment
    from .search import (
        DocumentCollectionSearchOptions,
        DocumentCollectionSearchResult,
        SearchDocumentCollectionResponse,
        SearchResultChunk,
        SingleFieldFilter,
    )
    from .users import UserMetadataPatch
    from .version import __version__
_dynamic_imports: typing.Dict[str, str] = {
    "AiEndpointConfiguration": ".copilots",
    "AsyncCredalApi": ".client",
    "BlockedChunk": ".copilots",
    "BooleanFieldSchema": ".copilots",
    "Collaborator": ".common",
    "CollectionFilteredData": ".copilots",
    "Configuration": ".copilots",
    "CreateCollectionResponse": ".document_collections",
    "CreateConversationResponse": ".copilots",
    "CreateCopilotResponse": ".copilots",
    "CredalApi": ".client",
    "CredalApiEnvironment": ".environment",
    "CustomMetadataValue": ".common",
    "DataChunk": ".copilots",
    "DataFilter": ".copilots",
    "DatetimeFieldSchema": ".copilots",
    "DeleteCollectionResponse": ".document_collections",
    "DeleteCopilotResponse": ".copilots",
    "DocumentCollectionSearchOptions": ".search",
    "DocumentCollectionSearchResult": ".search",
    "DocumentMetadataPatch": ".document_catalog",
    "DocumentMetadataPatchRequest": ".document_catalog",
    "EndOfMessageChunk": ".copilots",
    "ErrorChunk": ".copilots",
    "ErrorChunkData": ".copilots",
    "ExportCopilotsResponse": ".copilots",
    "ExportedCopilot": ".copilots",
    "ExternalResourceId": ".common",
    "FeedbackEnum": ".copilots",
    "Filter": ".copilots",
    "Filter_Boolean": ".copilots",
    "Filter_Datetime": ".copilots",
    "Filter_Number": ".copilots",
    "Filter_String": ".copilots",
    "FinalChunk": ".copilots",
    "InitialChunk": ".copilots",
    "InputVariable": ".copilots",
    "InsertedAuditLog": ".copilots",
    "ListDocumentsInCollectionResponse": ".document_collections",
    "MessageBlocked": ".copilots",
    "MessageFeedback": ".copilots",
    "MessageReply": ".copilots",
    "MongoCollectionSyncConfig": ".document_collections",
    "MongoCollectionSyncResponse": ".document_collections",
    "MongoSourceFieldsConfig": ".document_collections",
    "NumberFieldSchema": ".copilots",
    "Operator": ".common",
    "ReferencedSource": ".copilots",
    "ResourceIdentifier": ".common",
    "ResourceIdentifier_ExternalResourceId": ".common",
    "ResourceIdentifier_Url": ".common",
    "ResourceType": ".common",
    "ResponseChunk": ".copilots",
    "Role": ".common",
    "SearchDocumentCollectionResponse": ".search",
    "SearchResultChunk": ".search",
    "SendAgentMessageResponse": ".copilots",
    "SendMessageResponse": ".copilots",
    "SendMessageResponse_AiResponseResult": ".copilots",
    "SendMessageResponse_BlockedResult": ".copilots",
    "SingleFieldFilter": ".search",
    "StreamingChunk": ".copilots",
    "StreamingChunk_Blocked": ".copilots",
    "StreamingChunk_DataChunk": ".copilots",
    "StreamingChunk_EndOfMessage": ".copilots",
    "StreamingChunk_ErrorChunk": ".copilots",
    "StreamingChunk_FinalChunk": ".copilots",
    "StreamingChunk_Initial": ".copilots",
    "StringFieldSchema": ".copilots",
    "SyncSourceByUrlRequest": ".document_catalog",
    "SyncSourceByUrlResponse": ".document_catalog",
    "UploadDocumentResponse": ".document_catalog",
    "Url": ".common",
    "UserMetadataPatch": ".users",
    "WebSearchResult": ".copilots",
    "__version__": ".version",
    "common": ".common",
    "copilots": ".copilots",
    "document_catalog": ".document_catalog",
    "document_collections": ".document_collections",
    "search": ".search",
    "users": ".users",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AiEndpointConfiguration",
    "AsyncCredalApi",
    "BlockedChunk",
    "BooleanFieldSchema",
    "Collaborator",
    "CollectionFilteredData",
    "Configuration",
    "CreateCollectionResponse",
    "CreateConversationResponse",
    "CreateCopilotResponse",
    "CredalApi",
    "CredalApiEnvironment",
    "CustomMetadataValue",
    "DataChunk",
    "DataFilter",
    "DatetimeFieldSchema",
    "DeleteCollectionResponse",
    "DeleteCopilotResponse",
    "DocumentCollectionSearchOptions",
    "DocumentCollectionSearchResult",
    "DocumentMetadataPatch",
    "DocumentMetadataPatchRequest",
    "EndOfMessageChunk",
    "ErrorChunk",
    "ErrorChunkData",
    "ExportCopilotsResponse",
    "ExportedCopilot",
    "ExternalResourceId",
    "FeedbackEnum",
    "Filter",
    "Filter_Boolean",
    "Filter_Datetime",
    "Filter_Number",
    "Filter_String",
    "FinalChunk",
    "InitialChunk",
    "InputVariable",
    "InsertedAuditLog",
    "ListDocumentsInCollectionResponse",
    "MessageBlocked",
    "MessageFeedback",
    "MessageReply",
    "MongoCollectionSyncConfig",
    "MongoCollectionSyncResponse",
    "MongoSourceFieldsConfig",
    "NumberFieldSchema",
    "Operator",
    "ReferencedSource",
    "ResourceIdentifier",
    "ResourceIdentifier_ExternalResourceId",
    "ResourceIdentifier_Url",
    "ResourceType",
    "ResponseChunk",
    "Role",
    "SearchDocumentCollectionResponse",
    "SearchResultChunk",
    "SendAgentMessageResponse",
    "SendMessageResponse",
    "SendMessageResponse_AiResponseResult",
    "SendMessageResponse_BlockedResult",
    "SingleFieldFilter",
    "StreamingChunk",
    "StreamingChunk_Blocked",
    "StreamingChunk_DataChunk",
    "StreamingChunk_EndOfMessage",
    "StreamingChunk_ErrorChunk",
    "StreamingChunk_FinalChunk",
    "StreamingChunk_Initial",
    "StringFieldSchema",
    "SyncSourceByUrlRequest",
    "SyncSourceByUrlResponse",
    "UploadDocumentResponse",
    "Url",
    "UserMetadataPatch",
    "WebSearchResult",
    "__version__",
    "common",
    "copilots",
    "document_catalog",
    "document_collections",
    "search",
    "users",
]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing
import uuid

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .inserted_audit_log import InsertedAuditLog
from .referenced_source import ReferencedSource
from .response_chunk import ResponseChunk
from .web_search_result import WebSearchResult


class SendMessageResponse_AiResponseResult(UniversalBaseModel):
    type: typing.Literal["ai_response_result"] = "ai_response_result"
    conversation_id: typing_extensions.Annotated[uuid.UUID, FieldMetadata(alias="conversationId")]
    response: ResponseChunk
    warnings: typing.List[str]
    inserted_audit_log: InsertedAuditLog
    referenced_sources: typing_extensions.Annotated[
        typing.List[ReferencedSource], FieldMetadata(alias="referencedSources")
    ]
    sources_in_data_context: typing_extensions.Annotated[
        typing.List[ReferencedSource], FieldMetadata(alias="sourcesInDataContext")
    ]
    web_search_results: typing_extensions.Annotated[
        typing.List[WebSearchResult], FieldMetadata(alias="webSearchResults")
    ]
    message_id: typing_extensions.Annotated[uuid.UUID, FieldMetadata(alias="messageId")]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class SendMessageResponse_BlockedResult(UniversalBaseModel):
    type: typing.Literal["blocked_result"] = "blocked_result"
    conversation_id: typing_extensions.Annotated[uuid.UUID, FieldMetadata(alias="conversationId")]
    blocks: typing.List[str]
    warnings: typing.List[str]
    inserted_audit_log: InsertedAuditLog

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


SendMessageResponse = typing_extensions.Annotated[
    typing.Union[SendMessageResponse_AiResponseResult, SendMessageResponse_BlockedResult],
    pydantic.Field(discriminator="type"),
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        AiEndpointConfiguration,
        BlockedChunk,
        BooleanFieldSchema,
        CollectionFilteredData,
        Configuration,
        CreateConversationResponse,
        CreateCopilotResponse,
        DataChunk,
        DataFilter,
        DatetimeFieldSchema,
        DeleteCopilotResponse,
        EndOfMessageChunk,
        ErrorChunk,
        ErrorChunkData,
        ExportCopilotsResponse,
        ExportedCopilot,
        FeedbackEnum,
        Filter,
        Filter_Boolean,
        Filter_Datetime,
        Filter_Number,
        Filter_String,
        FinalChunk,
        InitialChunk,
        InputVariable,
        InsertedAuditLog,
        MessageBlocked,
        MessageFeedback,
        MessageReply,
        NumberFieldSchema,
        ReferencedSource,
        ResponseChunk,
        SendAgentMessageResponse,
        SendMessageResponse,
        SendMessageResponse_AiResponseResult,
        SendMessageResponse_BlockedResult,
        StreamingChunk,
        StreamingChunk_Blocked,
        StreamingChunk_DataChunk,
        StreamingChunk_EndOfMessage,
        StreamingChunk_ErrorChunk,
        StreamingChunk_FinalChunk,
        StreamingChunk_Initial,
        StringFieldSchema,
        WebSearchResult,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "AiEndpointConfiguration": ".types",
    "BlockedChunk": ".types",
    "BooleanFieldSchema": ".types",
    "CollectionFilteredData": ".types",
    "Configuration": ".types",
    "CreateConversationResponse": ".types",
    "CreateCopilotResponse": ".types",
    "DataChunk": ".types",
    "DataFilter": ".types",
    "DatetimeFieldSchema": ".types",
    "DeleteCopilotResponse": ".types",
    "EndOfMessageChunk": ".types",
    "ErrorChunk": ".types",
    "ErrorChunkData": ".types",
    "ExportCopilotsResponse": ".types",
    "ExportedCopilot": ".types",
    "FeedbackEnum": ".types",
    "Filter": ".types",
    "Filter_Boolean": ".types",
    "Filter_Datetime": ".types",
    "Filter_Number": ".types",
    "Filter_String": ".types",
    "FinalChunk": ".types",
    "InitialChunk": ".types",
    "InputVariable": ".types",
    "InsertedAuditLog": ".types",
    "MessageBlocked": ".types",
    "MessageFeedback": ".types",
    "MessageReply": ".types",
    "NumberFieldSchema": ".types",
    "ReferencedSource": ".types",
    "ResponseChunk": ".types",
    "SendAgentMessageResponse": ".types",
    "SendMessageResponse": ".types",
    "SendMessageResponse_AiResponseResult": ".types",
    "SendMessageResponse_BlockedResult": ".types",
    "StreamingChunk": ".types",
    "StreamingChunk_Blocked": ".types",
    "StreamingChunk_DataChunk": ".types",
    "StreamingChunk_EndOfMessage": ".types",
    "StreamingChunk_ErrorChunk": ".types",
    "StreamingChunk_FinalChunk": ".types",
    "StreamingChunk_Initial": ".types",
    "StringFieldSchema": ".types",
    "WebSearchResult": ".types",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "AiEndpointConfiguration",
    "BlockedChunk",
    "BooleanFieldSchema",
    "CollectionFilteredData",
    "Configuration",
    "CreateConversationResponse",
    "CreateCopilotResponse",
    "DataChunk",
    "DataFilter",
    "DatetimeFieldSchema",
    "DeleteCopilotResponse",
    "EndOfMessageChunk",
    "ErrorChunk",
    "ErrorChunkData",
    "ExportCopilotsResponse",
    "ExportedCopilot",
    "FeedbackEnum",
    "Filter",
    "Filter_Boolean",
    "Filter_Datetime",
    "Filter_Number",
    "Filter_String",
    "FinalChunk",
    "InitialChunk",
    "InputVariable",
    "InsertedAuditLog",
    "MessageBlocked",
    "MessageFeedback",
    "MessageReply",
    "NumberFieldSchema",
    "ReferencedSource",
    "ResponseChunk",
    "SendAgentMessageResponse",
    "SendMessageResponse",
    "SendMessageResponse_AiResponseResult",
    "SendMessageResponse_BlockedResult",
    "StreamingChunk",
    "StreamingChunk_Blocked",
    "StreamingChunk_DataChunk",
    "StreamingChunk_EndOfMessage",
    "StreamingChunk_ErrorChunk",
    "StreamingChunk_FinalChunk",
    "StreamingChunk_Initial",
    "StringFieldSchema",
    "WebSearchResult",
]



# This file was auto-generated by Fern from our API Definition.

import typing
import uuid

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .inserted_audit_log import InsertedAuditLog


class MessageBlocked(UniversalBaseModel):
    conversation_id: typing_extensions.Annotated[uuid.UUID, FieldMetadata(alias="conversationId")]
    blocks: typing.List[str]
    warnings: typing.List[str]
    inserted_audit_log: InsertedAuditLog

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata
from .exported_copilot import ExportedCopilot


class ExportCopilotsResponse(UniversalBaseModel):
    data: typing.List[ExportedCopilot] = pydantic.Field()
    """
    List of exported copilots matching the query filters.
    """

    has_more: typing_extensions.Annotated[bool, FieldMetadata(alias="hasMore")] = pydantic.Field()
    """
    Indicates whether there are more results available for pagination.
    """

    next_cursor: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="nextCursor")] = pydantic.Field(
        default=None
    )
    """
    Cursor to use for fetching the next page of results. This is a UUID string. If null or not present, there are no more results.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...common.types.resource_identifier import ResourceIdentifier
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ...core.serialization import FieldMetadata


class DocumentMetadataPatch(UniversalBaseModel):
    resource_identifier: typing_extensions.Annotated[ResourceIdentifier, FieldMetadata(alias="resourceIdentifier")] = (
        pydantic.Field()
    )
    """
    The identifier for the resource you want to patch
    """

    metadata: typing.Dict[str, typing.Any] = pydantic.Field()
    """
    Key-value object of metadata for document. Keys will be merged with any existing values but can also be set to `null` to effectively remove
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
